@@ -32,9 +32,7 @@
 int
 getentropy(void *buf, size_t len);
 
-#if defined(__OpenBSD__)
-#include "arc4random_openbsd.h"
-#elif defined(__linux__)
+#if defined(__linux__)
 #include "arc4random_linux.h"
 #elif defined(_WIN32)
 #include "arc4random_win.h"
